# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""multistage restores scripts

Revision ID: 8e38c2b4bbdd
Revises: 5661f79ddf29
Create Date: 2021-10-11 15:56:02.052972

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "8e38c2b4bbdd"
down_revision = "5661f79ddf29"
branch_labels = None
depends_on = None

fetch_content = """#!/bin/sh

export HOME=$TMPDIR

set -o errexit
./framework.sh -d .
chmod 770 .
cd rawdata/
../productfetcher --product-locator $1 --product-locator $2
cd ../

"""

envoy_content = """#!/bin/sh

export HOME=$TMPDIR

set -o errexit

{{#remote}}
export CAPO_PATH=.
export CAPO_PROFILE={{profile}}
{{/remote}}
./casa_envoy --restore -c $1 $2

"""

deliver_content = """#!/bin/sh

export HOME=$TMPDIR

set -o errexit

cp -r ./working/{{sdmId}}.ms ./products/
./deliver -p ./products --prefix $1

"""

old_content = """#!/bin/sh

export HOME=$TMPDIR

set -o errexit
./framework.sh -d .
chmod 770 .
cd rawdata/
../productfetcher --product-locator $1 --product-locator $2
cd ../
./casa_envoy --restore -c $4 $5
cp -r ./working/{{sdmId}}.ms ./products/
./deliver -p ./products --prefix $3
"""


def upgrade():
    op.execute(
        """
        DELETE FROM workflow_templates WHERE filename='restore_cms.sh'
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name)
        VALUES ('restore_cms_fetch.sh', E'{fetch_content}', 'restore_cms')
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name)
        VALUES ('restore_cms_envoy.sh', E'{envoy_content}', 'restore_cms')
        """
    )
    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name)
        VALUES ('restore_cms_deliver.sh', E'{deliver_content}', 'restore_cms')
        """
    )


def downgrade():
    op.execute(
        """
        DELETE FROM workflow_templates
        WHERE filename like ('restore_cms_%.sh')
        AND workflow_name = 'restore_cms'
        """
    )

    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name)
        VALUES ('restore_cms.sh', E'{old_content}', 'restore_cms')
        """
    )
